<?php

/**------------------------------------------------
*
* Rooty, 2021 <rooty@rooty.me>
*
*
* This software is protected by copyright, please
* read the file COPYRIGHT.
* This program is distributed in the hope that it
* will be useful, but without any warranty; without
* even the implied warranty of merchantability or
* fitness for a particular purpose. Please
* read the file LICENCE.
*
* Fichier NodeSettingsManagerDb.php
*
* Ce fichier contient la classe NodeSettingsManagerDb
*
* @author Rooty <www.rooty.me|rooty@rooty.me>
* @link www.rooty.me
* @since 2021/04/19
* @version 0.1
* @package system_data
* @subpackage NodeSettings
* @copyright Copyright &copy; 2021, Rooty
*/

#####################################################################################################
################################# Parametrage
#####################################################################################################
/**
* declaration du system... si cette variable n'est pas définie, les fichier inclus ne marche pas...
* cette variable est déclarée sur la page d'execution du script.
*<p> if ( !defined('SYSTEM_IN') )
* {
* die("Hacking attempt");
* }</p>
*/
if ( !defined('SYSTEM_IN') )
{
 die("Hacking attempt");
}

/**
* Classe NodeSettingsManagerDb
*
* classe de gestion des Nodes pour une do de données database (type gérés par database)<br><br>
* Sont configuré dans config_data_acces.php:<br>
* - La do d'information <br>
*    (actuellement seul DB possible->Pour ajouter une do reproduire NodeNodeSettingsManagerDb)<br>
* - Le Nom de la Table<br>
* - La configuration (Paramétrage des dos de do de données) est faite dans config_data_do.php<br>
* - La declaration de la connexion est faite à partir de config_system.php
*
* @package system_data
* @subpackage NodeSettings
*/
class NodeSettingsManagerDb extends NodeSettingsManager
{

/**
* @var chaine
* @access private
* @desc ID de la Node
*/
var $table		= "";

/**
* @var object
* @access private
* @desc objet database
*/
var $conn		= null;

	//
	// Constructor
	//

/**
* Constructeur de la classe NodeSettingsManagerDb PHP4
*
* <p>Initialise la NodeSettingsManagerDb</p>
* @access public
*/
	function NodeSettingsManagerDb()
	{
		$this->__construct();
	}

/**
* Constructeur de la classe NodeSettingsManagerDb PHP5
*
* <p>Initialise la NodeSettingsManagerDb</p>
* @access public
*/
	function __construct()
	{
		$this->setTable( DATA_ACCES_TABLE_NODESETTINGS );	/* Appel à la constant correspondant */
		$this->initSqlAttribut();			/* initialisation des noms de champs */
		$this->setConn($GLOBALS['SYSTEM_DATABASE_CONN']);
	}

/**
* getTable : recupere le nom de la table utilisée
* @access public
* @return chaine
*/
	function getTable()
	{
		return $this->table;
	}

/**
* setTable : recupere le nom de la table utilisée
* @access public
* @param chaine nom de la table
* @return chaine
*/
	function setTable($chaine)
	{
		if (!is_string($chaine))
			return false;

		$this->table=$chaine;
		return true;
	}

/**
* getTable : recupere le nom de la table utilisée
* @access public
* @return chaine
*/
	function getConn()
	{
		return $this->conn;
	}

/**
* setTable : recupere le nom de la table utilisée
* @access public
* @param object objet classe "database"
* @return chaine
*/
	function setConn(&$obj)
	{
		if (!is_object($obj))
			return false;

		$this->conn=&$obj;
		return true;
	}

/**
* doLoadFromId: Charge le Noeud depuis la BD
*
* <p>Retourne un tableau contenant les infos de l'objet</p>
* @access private
* @param entier identifiant du Noeud
* @return tableau
*/
	function doLoadFromId($id)
	{
		$sql = "SELECT * FROM ".$this->getTable()." WHERE ".$this->getSqlName("id")."=".$id;
// 		$sql.= " AND ".$this->getSqlName("domain")."=".$_SERVER["SERVER_NAME"];
		
		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_numrows()==0)
		{
			$systemError=1;
			$classe="NodeSettings";
			$message="Erreur du load from id dans l'objet FetchNodeSettingsManagerDb LoadFromId, avec l'id=".$id;
			addError($systemError,$classe,$message, __line__, __file__);
			return array();
		}

		$tab=$this->conn->sql_fetchrow();
		$tab=$this->translateArray($tab);

		# Destruction des éléments
		$this->conn->sql_freeresult();
		return $tab;
	}

/**
* doInsert: Insert le Noeud dans la BD
*
* <P>Insertion dans la Bd</P>
* @param entier identifiant du pére
* @param chaine libelle de du noeud
* @param chaine icone de du noeud
* @access private
* @return entier
*/
	function doInsert($id, $email, $git, $mastodon, $mobilizon, $matrix, $peertube, $nextcloud, $twitter, $facebook)
	{
		$sql="INSERT INTO ".$this->getTable()." ("
			.$this->getSqlName("id").", "
			.$this->getSqlName("email").", "
			.$this->getSqlName("git").", "
			.$this->getSqlName("mastodon").", "
			.$this->getSqlName("mobilizon").", "
			.$this->getSqlName("matrix").", "
			.$this->getSqlName("peertube").", "
			.$this->getSqlName("nextcloud").", "
			.$this->getSqlName("twitter").", "
			.$this->getSqlName("facebook").") VALUES (";
		$sql.= $id.", '".$email."', '".$git."', '".$mastodon."', '".$mobilizon."', '".$matrix."', '".$peertube."', '".$nextcloud."', '".$twitter."', '".$facebook."')";

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_affectedrows()==0)
		{
			$systemError=1;
			$classe="NodeSettings";
			$message="Erreur d'INSERTION dans FetchNodeSettingsManagerDb avec le courriel".$email."\n".$sql;
			addError($systemError,$classe,$message, __line__, __file__);
			return 0;
		}
		$retour=$this->conn->sql_nextid();
		return $retour;
	}

/**
* doUpdate : Modifie le Noeud dans la BD
*
* <P>Mise à jour de la Node</P>
* @param entier identifiant
* @param entier identifiant du pére
* @param chaine libelle de du noeud
* @param chaine icone de du noeud
* @access private
* @return booleen
*/
	function doUpdate($id, $email, $git, $mastodon, $mobilizon, $matrix, $peertube, $nextcloud, $twitter, $facebook)
	{
		$sql="UPDATE ".$this->getTable()." SET "
			.$this->getSqlName("id")."='".$id."', "
			.$this->getSqlName("email")."='".$email."', "
			.$this->getSqlName("git")."='".$git."', "
			.$this->getSqlName("mastodon")."='".$mastodon."', "
			.$this->getSqlName("mobilizon")."='".$mobilizon."', "
			.$this->getSqlName("matrix")."='".$matrix."', "
			.$this->getSqlName("peertube")."='".$peertube."', "
			.$this->getSqlName("nextcloud")."='".$nextcloud."', "
			.$this->getSqlName("twitter")."='".$twitter."', "
			.$this->getSqlName("facebook")."='".$facebook."' WHERE ";
		$sql.=$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);
		$retour=$id;
		return $retour;
	}

/**
* doDelete : Detruit le Noeud dans la BD
*
* <p>Suppression du noeud à partir de son identifiant</p>
* @param entier identifiant du Noeud
* @access private
* @return booleen
*/
	function doDelete($id)
	{
		$sql="DELETE FROM ".$this->getTable()." WHERE ".$this->getSqlName("id")."=".$id;

		# Requete
		$result=$this->conn->sql_query($sql);

		if ($this->conn->sql_affectedrows()==0)
		{
			$systemError=1;
			$classe="NodeSettings";
			$message="Erreur de SUPPRESSION dans FetchNodeSettingsManagerDb avec l'id ".$id;
			addError($systemError,$classe,$message, __line__, __file__);
			return false;
		}
		return true;
	}

	//////////////////////////////////////////////////////////////////////////
	//
	// Utilitaires pour la gestion des compatibilités BD
	//
	/////////////////////////////////////////////////////////////////////////
/**
* translateKey : change les cles du tableau resultant d'une requete en tableau de données pour l'objet
*
* <p>Supprime le nom de la table dans les noms de champs renvoyés par la BD<br/>
* garde la compatibilité avec les version précédentes</p>
* @param array tableau sql
* @access private
* @return array tableau des attributs
*/
	function translateArray($sqlArray)
	{
		/* Cas nouvelle BD systeme */
		$result["id"]				=$sqlArray[$this->getSqlName('id')];
		$result["email"]			=$sqlArray[$this->getSqlName("email")];
		$result["git"]				=$sqlArray[$this->getSqlName("git")];
		$result["mastodon"]			=$sqlArray[$this->getSqlName("mastodon")];
		$result["mobilizon"]		=$sqlArray[$this->getSqlName("mobilizon")];
		$result["matrix"]			=$sqlArray[$this->getSqlName("matrix")];
		$result["peertube"]			=$sqlArray[$this->getSqlName("peertube")];
		$result["nextcloud"]		=$sqlArray[$this->getSqlName("nextcloud")];
		$result["twitter"]			=$sqlArray[$this->getSqlName("twitter")];
		$result["facebook"]			=$sqlArray[$this->getSqlName("facebook")];
		return $result;
	}

/**
* initSqlAttributName : recupere le nom d'un attribut a partir d'une cle
*
* <p>En fonction de la version sql, on trouvera ici la correspondance entre le nom attribut de l'objet et son nom en BD<br/>
* cette methode permet de garder la compatibilité avec les version précédentes</p>
* @param chaine nom de l'attribut recherche
* @access private
* @return booleen
*/
	function initSqlAttribut()
	{
		if(defined('DATA_ACCES_TABLE_VERSION'))
		{
			if( DATA_ACCES_TABLE_VERSION == 1)
			{
				$this->sqlAttributArray["id"]				="node_id";
				$this->sqlAttributArray["email"]			="node_email";
				$this->sqlAttributArray["git"]				="node_git";
				$this->sqlAttributArray["mastodon"]			="node_mastodon";
				$this->sqlAttributArray["mobilizon"]		="node_mobilizon";
				$this->sqlAttributArray["matrix"]			="node_matrix";
				$this->sqlAttributArray["peertube"]			="node_peertube";
				$this->sqlAttributArray["nextcloud"]		="node_nextcloud";
				$this->sqlAttributArray["twitter"]			="node_twitter";
				$this->sqlAttributArray["facebook"]			="node_facebook";
				return true;
			}
		}
		$this->sqlAttributArray["id"]				="id";
		$this->sqlAttributArray["email"]			="email";
		$this->sqlAttributArray["git"]				="git";
		$this->sqlAttributArray["mastodon"]			="mastodon";
		$this->sqlAttributArray["mobilizon"]		="mobilizon";
		$this->sqlAttributArray["matrix"]			="matrix";
		$this->sqlAttributArray["peertube"]			="peertube";
		$this->sqlAttributArray["nextcloud"]		="nextcloud";
		$this->sqlAttributArray["twitter"]			="twitter";
		$this->sqlAttributArray["facebook"]			="facebook";
		return true;
	}

/**
* getSqlName : recupere le nom du champ a partir d'une cle
*
* <p>En fonction de la version sql, on trouvera ici la correspondance entre le nom attribut de l'objet et son nom en BD<br/>
* Cette methode permet de garder la compatibilite avec les version précédentes<br/>
* Elle s'appuie sur le tableau associatif $this->sqlAttributArray genere par initSqlAttributArray</p>
* @param chaine nom de l'attribut recherche
* @access private
* @return chaine nom du champ sql
*/
	function getSqlName($attribut)
	{
		return ( (isset($this->sqlAttributArray[$attribut]))?$this->sqlAttributArray[$attribut]:$attribut );
	}
}
?>
